<?php
/**
 * Plugin Name: Autoblogging.ai Monetizer
 * Description: Monetize your sites with easy code insertions. Automatically inserts an ad snippet after every 'n' paragraphs in posts. Co-developed by Julian Goldie (JulianGoldie.com).
 * Version: 1.8
 * Author: Autoblogging.ai
 * Author URI: https://Autoblogging.ai
 */

// Admin menu setup
function cai_admin_menu() {
    add_menu_page('Autoblogging Monetization', 'Autoblogging Monetization', 'manage_options', 'autoblogging-monetization', 'cai_settings_page');
}
add_action('admin_menu', 'cai_admin_menu');

// Settings page content
function cai_settings_page() {
    ?>
    <div class="wrap">
    <h1>Autoblogging Monetization Settings</h1>
	<p>This plugin is co-developed by <a href="https://Autoblogging.ai/" target="_blank">Autoblogging.ai</a> and <a href="https://Juliangoldie.com/" target="_blank">Julian Goldie</a>.
    <form method="post" action="options.php">
        <?php
        settings_fields('cai-settings');
        do_settings_sections('cai-settings');
        submit_button();
        ?>
    </form>
    </div>
    <?php
}

// Initialize settings
function cai_settings_init() {
    register_setting('cai-settings', 'cai_paragraph_gap');
    register_setting('cai-settings', 'cai_ad_code');

    add_settings_section('cai_settings_section', 'Settings', 'cai_settings_section_cb', 'cai-settings');
    add_settings_field('cai_paragraph_gap', 'Paragraph Gap', 'cai_paragraph_gap_cb', 'cai-settings', 'cai_settings_section');
    add_settings_field('cai_ad_code', 'Ad Code', 'cai_ad_code_cb', 'cai-settings', 'cai_settings_section');
}
add_action('admin_init', 'cai_settings_init');

// Settings section callback
function cai_settings_section_cb() {
    echo '<p>Set your preferences below.</p>';
}

// Paragraph gap field callback
function cai_paragraph_gap_cb() {
    $gap = get_option('cai_paragraph_gap');
    echo '<input type="number" id="cai_paragraph_gap" name="cai_paragraph_gap" value="' . esc_attr($gap) . '" />';
}

// Ad code field callback
function cai_ad_code_cb() {
    $code = get_option('cai_ad_code');
    echo '<textarea id="cai_ad_code" name="cai_ad_code" rows="10" cols="50">' . esc_textarea($code) . '</textarea>';
}

// Insert ad into content
function cai_insert_ad($content) {
    if (!is_single()) return $content;

    $gap = get_option('cai_paragraph_gap', 3); // Default gap is 3 paragraphs
    $ad_code = get_option('cai_ad_code');

    if (!$gap || !$ad_code) return $content;

    $paragraphs = explode('</p>', $content);
    $new_content = '';
    $count = 0;

    foreach ($paragraphs as $paragraph) {
        $new_content .= $paragraph . '</p>';
        if (++$count % $gap == 0) {
            $new_content .= $ad_code;
        }
    }

    return $new_content;
}
add_filter('the_content', 'cai_insert_ad');

// Activation hook
function cai_activate() {
    add_option('cai_paragraph_gap', '3');
    add_option('cai_ad_code', '');
}
register_activation_hook(__FILE__, 'cai_activate');

// Deactivation hook
function cai_deactivate() {
    delete_option('cai_paragraph_gap');
    delete_option('cai_ad_code');
}
register_deactivation_hook(__FILE__, 'cai_deactivate');
